@@ -4,7 +4,7 @@ from typing import Union
 from eda_report.document import ReportDocument
 from eda_report.multivariate import MultiVariable
 
-__version__ = "2.6.0"
+__version__ = "2.7.0"
 
 
 def get_word_report(
@@ -12,7 +12,7 @@ def get_word_report(
     *,
     title: str = "Exploratory Data Analysis Report",
     graph_color: str = "cyan",
-    target_variable: Union[str, int] = None,
+    groupby_data: Union[str, int] = None,
     output_filename: str = "eda-report.docx",
     table_style: str = "Table Grid",
 ) -> ReportDocument:
@@ -24,10 +24,10 @@ def get_word_report(
             "Exploratory Data Analysis Report".
         graph_color (str, optional): The color to apply to the graphs.
             Defaults to "cyan".
-        target_variable (Union[str, int], optional): The label/index for the
+        groupby_data (Union[str, int], optional): The label/index for the
             column to use to group values. Defaults to None.
-        output_filename (str, optional): The name and location to save the
-         report document. Defaults to "eda-report.docx".
+        output_filename (str, optional): The name and path to save the report
+            document. Defaults to "eda-report.docx".
         table_style (str, optional): The style to apply to the tables created.
             Defaults to "Table Grid".
 
@@ -36,7 +36,7 @@ def get_word_report(
 
     Example:
         .. literalinclude:: examples.txt
-           :lines: 148-155
+           :lines: 145-150
 
     """
     return ReportDocument(
@@ -44,7 +44,7 @@ def get_word_report(
         title=title,
         graph_color=graph_color,
         output_filename=output_filename,
-        target_variable=target_variable,
+        groupby_data=groupby_data,
         table_style=table_style,
     )
 
@@ -60,7 +60,7 @@ def summarize(data: Iterable) -> MultiVariable:
 
     Examples:
         .. literalinclude:: examples.txt
-           :lines: 159-217
+           :lines: 154-210
 
     """
     return MultiVariable(data)
