@@ -2,11 +2,12 @@ import logging
 from typing import Iterable, Sequence, Union
 
 from docx import Document
+from docx.enum.text import WD_ALIGN_PARAGRAPH
 from docx.shared import Inches, Pt
 from docx.text.parfmt import ParagraphFormat
 from pandas.core.frame import DataFrame
 
-from eda_report.content import ReportContent
+from eda_report.content import _ReportContent
 
 logging.basicConfig(
     format="[%(levelname)s %(asctime)s.%(msecs)03d] %(message)s",
@@ -15,19 +16,15 @@ logging.basicConfig(
 )
 
 
-class ReportDocument(ReportContent):
-    """Creates a :class:`~docx.document.Document`  with analysis results.
-
-    The :class:`~eda_report.content.ReportContent` class is used to analyze
-    the data and generate text and graph content. Then the
-    :class:`~docx.document.Document` class from the `python-docx`_ package is
-    used to publish the results as a *Word* document.
+class ReportDocument(_ReportContent):
+    """Creates a :class:`~docx.document.Document` with analysis results
+    using `python-docx`_.
 
     The report consists of 3 main sections:
 
-    #. An *Overview* of the data and its features.
-    #. *Univariate Analysis*: Summary statistics and graphs for each feature.
-    #. *Bivariate Analysis*: Pairwise comparisons of numerical features.
+    #. An **Overview** of the data and its features.
+    #. **Univariate Analysis**: Summary statistics and graphs for each feature.
+    #. **Bivariate Analysis**: Pairwise comparisons of numerical features.
 
     .. _python-docx: https://python-docx.readthedocs.io/en/latest/
 
@@ -37,7 +34,7 @@ class ReportDocument(ReportContent):
             "Exploratory Data Analysis Report".
         graph_color (str, optional): The color to apply to the graphs.
             Defaults to "cyan".
-        target_variable (Union[str, int], optional): The column to
+        groupby_data (Union[str, int], optional): The column to
             use to group values. Defaults to None.
         output_filename (str, optional): The file name or path to save the
             document to. Defaults to "eda-report.docx".
@@ -51,7 +48,7 @@ class ReportDocument(ReportContent):
         *,
         title: str = "Exploratory Data Analysis Report",
         graph_color: str = "cyan",
-        target_variable: Union[str, int] = None,
+        groupby_data: Union[str, int] = None,
         output_filename: str = "eda-report.docx",
         table_style: str = "Table Grid",
     ) -> None:
@@ -59,7 +56,7 @@ class ReportDocument(ReportContent):
             data,
             title=title,
             graph_color=graph_color,
-            target_variable=target_variable,
+            groupby_data=groupby_data,
         )
         self.OUTPUT_FILENAME = output_filename
         self.TABLE_STYLE = table_style
@@ -90,14 +87,14 @@ class ReportDocument(ReportContent):
         self.document.add_page_break()
 
     def _format_heading_spacing(
-        self, format: ParagraphFormat, before: int = 21, after: int = 7
+        self, format: ParagraphFormat, before: int = 15, after: int = 7
     ) -> None:
         """Set the spacing above or below a heading.
 
         Args:
             format (ParagraphFormat): The heading's format.
             before (int, optional): Size of spacing above the heading in pt.
-                Defaults to 21.
+                Defaults to 15.
             after (int, optional): Size of spacing below the heading in pt.
                 Defaults to 7.
         """
@@ -155,19 +152,29 @@ class ReportDocument(ReportContent):
                 f"1.{idx}. {var_name}".title(), level=2
             )
             self._format_heading_spacing(
-                heading.paragraph_format, before=20, after=5
+                heading.paragraph_format, before=12, after=5
             )
             self.document.add_paragraph(var_info["description"])
 
-            self.document.add_heading("Summary Statistics", level=4)
+            stats_heading = self.document.add_heading(
+                "Summary Statistics", level=4
+            )
+            stats_heading.alignment = WD_ALIGN_PARAGRAPH.CENTER
+
             self._create_table(var_info["statistics"], column_widths=[2.5, 2])
 
-            for graph in var_info["graphs"].values():
+            for graph in (var_info["graphs"]).values():
                 self.document.add_picture(graph, width=Inches(4.4))
+                picture_paragraph = self.document.paragraphs[-1]
+                picture_paragraph.alignment = WD_ALIGN_PARAGRAPH.CENTER
 
             if (norm_tests := var_info["normality_tests"]) is not None:
 
-                self.document.add_heading("Tests for Normality", level=4)
+                norm_test_heading = self.document.add_heading(
+                    "Tests for Normality", level=4
+                )
+                norm_test_heading.alignment = WD_ALIGN_PARAGRAPH.CENTER
+
                 # type | p-value | conclusion
                 self._create_table(
                     data=norm_tests,
@@ -180,7 +187,7 @@ class ReportDocument(ReportContent):
         self.document.add_page_break()
 
     def _get_bivariate_analysis(self) -> None:
-        """Get comparisons, regression-plots and ecdf-plots for pairs of numeric
+        """Get comparisons and regression-plots for pairs of numeric
         variables.
         """
         bivariate_heading = self.document.add_heading(
@@ -191,9 +198,11 @@ class ReportDocument(ReportContent):
         )
 
         self.document.add_picture(
-            self.bivariate_graphs["correlation_heatmap"],
+            self.bivariate_graphs["correlation_plot"],
             width=Inches(6.7),
         )
+        picture_paragraph = self.document.paragraphs[-1]
+        picture_paragraph.alignment = WD_ALIGN_PARAGRAPH.CENTER
         self.document.add_page_break()
 
         for idx, var_pair in enumerate(self.bivariate_summaries, start=1):
@@ -201,17 +210,15 @@ class ReportDocument(ReportContent):
                 f"2.{idx} {var_pair[0]} vs {var_pair[1]}".title(), level=2
             )
             self._format_heading_spacing(
-                heading.paragraph_format, before=20, after=5
+                heading.paragraph_format, before=16, after=5
             )
             self.document.add_paragraph(self.bivariate_summaries[var_pair])
             self.document.add_picture(
                 self.bivariate_graphs["regression_plots"][var_pair],
-                width=Inches(6),
+                width=Inches(3.5),
             )
-
-            # Add a page break after every 2 pairs
-            if idx % 2 == 0:
-                self.document.add_page_break()
+            picture_paragraph = self.document.paragraphs[-1]
+            picture_paragraph.alignment = WD_ALIGN_PARAGRAPH.CENTER
 
     def _create_table(
         self,
@@ -249,6 +256,7 @@ class ReportDocument(ReportContent):
             cols=len(column_widths),
         )
         table.style = style or self.document.styles[self.TABLE_STYLE]
+        table.alignment = WD_ALIGN_PARAGRAPH.CENTER
 
         # Set column dimensions
         for idx, width in enumerate(column_widths):
@@ -257,7 +265,7 @@ class ReportDocument(ReportContent):
         # Populate the rows
         for idx, row_data in enumerate(data.itertuples()):
             for cell, value in zip(table.rows[idx].cells, row_data):
-                cell.text = f"{value}".rstrip('0').rstrip('.')
+                cell.text = f"{value}".rstrip("0").rstrip(".")
 
                 # Font size and type-face have to be set at `run` level
                 run = cell.paragraphs[0].runs[0]
